package com.ruoyi.asset.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.asset.utils.UserUtils;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.framework.web.service.TokenService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Service;
import com.ruoyi.asset.mapper.TbPlaceMapper;
import com.ruoyi.asset.domain.TbPlace;
import com.ruoyi.asset.service.ITbPlaceService;

/**
 * 地点Service业务层处理
 * 
 * @author 原动力
 * @date 2023-03-27
 */
@Service
public class TbPlaceServiceImpl extends ServiceImpl<TbPlaceMapper, TbPlace> implements ITbPlaceService
{
    @Autowired
    private TbPlaceMapper tbPlaceMapper;

    /**
     * 查询地点
     * 
     * @param id 地点主键
     * @return 地点
     */
    @Override
    public TbPlace selectTbPlaceById(Long id)
    {
        return tbPlaceMapper.selectTbPlaceById(id);
    }

    /**
     * 查询地点列表
     * 
     * @param tbPlace 地点
     * @return 地点
     */
    @Override
    public List<TbPlace> selectTbPlaceList(TbPlace tbPlace)
    {
        return tbPlaceMapper.selectTbPlaceList(tbPlace);
    }

    /**
     * 新增地点
     * 
     * @param tbPlace 地点
     * @return 结果
     */
    @Override
    public int insertTbPlace(TbPlace tbPlace)
    {
        return tbPlaceMapper.insertTbPlace(tbPlace);
    }

    /**
     * 修改地点
     * 
     * @param tbPlace 地点
     * @return 结果
     */
    @Override
    public int updateTbPlace(TbPlace tbPlace)
    {
        return tbPlaceMapper.updateTbPlace(tbPlace);
    }

    /**
     * 批量删除地点
     * 
     * @param ids 需要删除的地点主键
     * @return 结果
     */
    @Override
    public int deleteTbPlaceByIds(Long[] ids)
    {
        return tbPlaceMapper.deleteTbPlaceByIds(ids);
    }

    /**
     * 删除地点信息
     * 
     * @param id 地点主键
     * @return 结果
     */
    @Override
    public int deleteTbPlaceById(Long id)
    {
        return tbPlaceMapper.deleteTbPlaceById(id);
    }

    @Override
    public List<TbPlace> selectTbPlaceAll() {
        return list();
    }
}
